emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] emacs-25 9b0ffdb: Spelling fixes


From: Paul Eggert
Subject: [Emacs-diffs] emacs-25 9b0ffdb: Spelling fixes
Date: Mon, 07 Dec 2015 16:38:10 +0000

branch: emacs-25
commit 9b0ffdbaddec7d9d46dcd7fc525c4fde7c842c46
Author: Paul Eggert <address@hidden>
Commit: Paul Eggert <address@hidden>

    Spelling fixes
    
    * doc/misc/calc.texi (Predefined Units): Use the bland modern
    scientific style for spelling the units “ampere” and
    “angstrom” rather than the older style “Ampere” and
    “Ångstrom”.  The latter spelling was wrong anyway (it should
    have been “Ångström”).
    * lisp/emacs-lisp/ert.el (ert--explain-equal-rec):
    Fix misspelling of ‘atom’ in code.
---
 doc/misc/calc.texi                     |   18 ++++--------------
 lisp/emacs-lisp/ert.el                 |    2 +-
 src/emacs-module.c                     |    6 +++---
 test/automated/character-fold-tests.el |    2 +-
 4 files changed, 9 insertions(+), 19 deletions(-)

diff --git a/doc/misc/calc.texi b/doc/misc/calc.texi
index 8579d0f..02f9446 100644
--- a/doc/misc/calc.texi
+++ b/doc/misc/calc.texi
@@ -12597,7 +12597,6 @@ in this mode.  Explicit simplification commands, such 
as @kbd{=} or
 @xref{Algebraic Definitions}, for a sample use of
 No-Simplification mode.
 
-
 @kindex m N
 @pindex calc-num-simplify-mode
 The @kbd{m N} (@code{calc-num-simplify-mode}) command turns off simplification
@@ -22463,7 +22462,6 @@ Hyperbolic prefix @kbd{H} can be used similarly; the 
@kbd{H a s} will
 replace any hyperbolic functions in the formula with the appropriate
 combinations of @samp{sinh}s and @samp{cosh}s before simplifying.
 
-
 @menu
 * Basic Simplifications::
 * Algebraic Simplifications::
@@ -28032,7 +28030,7 @@ column of the Units Table.
 @noindent
 The definitions of many units have changed over the years.  For example,
 the meter was originally defined in 1791 as one ten-millionth of the
-distance from the equator to the north pole.  In order to be more
+distance from the Equator to the North Pole.  In order to be more
 precise, the definition was adjusted several times, and now a meter is
 defined as the distance that light will travel in a vacuum in
 1/299792458 of a second; consequently, the speed of light in a
@@ -28071,13 +28069,8 @@ of the various temperature scales.
 The unit of volume ``liters'' can be referred to by either the lower-case
 @code{l} or the upper-case @code{L}.
 
-The unit @code{A} stands for Amperes; the name @code{Ang} is used
address@hidden
-for \AA ngstroms.
address@hidden tex
address@hidden
-for Angstroms.
address@hidden ifnottex
+The unit @code{A} stands for amperes; the name @code{Ang} is used
+for angstroms.
 
 The unit @code{pt} stands for pints; the name @code{point} stands for
 a typographical point, defined by @samp{72 point = 1 in}.  This is
@@ -28099,7 +28092,6 @@ use the @samp{tex} prefix; the unit name for a @TeX{} 
point will be
 the unit names for pint and parsec will simply be @samp{pint} and
 @samp{parsec} instead of @samp{pt} and @samp{pc}.
 
-
 The unit @code{e} stands for the elementary (electron) unit of charge;
 because algebra command could mistake this for the special constant
 @expr{e}, Calc provides the alternate unit name @code{ech} which is
@@ -28496,7 +28488,6 @@ a frequency or a midi number to scientific pitch 
notation.  For
 example, @code{500 Hz} gets converted to
 @code{B_4 + 21.3094853649 cents} and @code{84} to @code{C_6}.
 
-
 @kindex l m
 @pindex calc-midi
 @tindex midi
@@ -28527,7 +28518,6 @@ notation @code{B_3 + 99.9962592773 cents}; with the 
default value of
 @code{1}, Calc converts @code{261.625 Hz} to @code{C_4}.
 
 
-
 @node Store and Recall, Graphics, Units, Top
 @chapter Storing and Recalling
 
@@ -29907,7 +29897,7 @@ The @kbd{C-y} command can be given a prefix, which will 
interpret the
 text being yanked with a different radix.  If the text being yanked can be
 interpreted as a binary, octal, hexadecimal, or decimal number, then a
 prefix of @kbd{2}, @kbd{8}, @kbd{6} or @kbd{0} will have Calc
-interpret the yanked text as a number in the appropriate base.  For example, 
+interpret the yanked text as a number in the appropriate base.  For example,
 if @samp{111} has just been killed and is yanked into Calc with a command
 of @kbd{C-2 C-y}, then the number @samp{7} will be put on the stack.
 If you use the plain prefix @kbd{C-u}, then you will be prompted for a
diff --git a/lisp/emacs-lisp/ert.el b/lisp/emacs-lisp/ert.el
index a75b23b..470fd49 100644
--- a/lisp/emacs-lisp/ert.el
+++ b/lisp/emacs-lisp/ert.el
@@ -515,7 +515,7 @@ Returns nil if they are."
                   for xi = (ert--explain-equal-rec ai bi)
                   do (when xi (cl-return `(array-elt ,i ,xi)))
                   finally (cl-assert (equal a b) t))))
-      ((pred atomp)
+      ((pred atom)
        (if (not (equal a b))
            (if (and (symbolp a) (symbolp b) (string= a b))
                `(different-symbols-with-the-same-name ,a ,b)
diff --git a/test/automated/character-fold-tests.el 
b/test/automated/character-fold-tests.el
index 4e8761e..c056862 100644
--- a/test/automated/character-fold-tests.el
+++ b/test/automated/character-fold-tests.el
@@ -113,7 +113,7 @@
         ;; Our initial implementation of case-folding in char-folding
         ;; created a lot of redundant paths in the regexp. Because of
         ;; that, if a really long string "almost" matches, the regexp
-        ;; engine took a long time to realise that it doesn't match.
+        ;; engine took a long time to realize that it doesn't match.
         (should-not (character-fold-search-forward (concat string "c") nil 
'noerror))
         ;; Ensure it took less than a second.
         (should (< (- (time-to-seconds (current-time))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/src/emacs-module.c b/src/emacs-module.c
index 9967fc4..620df93 100644
--- a/src/emacs-module.c
+++ b/src/emacs-module.c
@@ -906,7 +906,7 @@ value_to_lisp (emacs_value v)
 
 /* Attempt to convert O to an emacs_value.  Do not do any checking or
    or allocate any storage; the caller should prevent or detect
-   any resulting bitpattern that is not a valid emacs_value.  */
+   any resulting bit pattern that is not a valid emacs_value.  */
 static emacs_value
 lisp_to_value_bits (Lisp_Object o)
 {
@@ -932,7 +932,7 @@ lisp_to_value (Lisp_Object o)
 
   if (! EQ (o, value_to_lisp_bits (v)))
     {
       /* Package the uncompressible object pointer inside a pair
         that is compressible.  */
       Lisp_Object pair = Fcons (o, ltv_mark);
 
@@ -944,7 +944,7 @@ lisp_to_value (Lisp_Object o)
            pair = Fcons (o, pair);
 
          /* Plant the mark.  The garbage collector will eventually
-            reclaim any just-allocated uncompressible pairs.  */
+            reclaim any just-allocated incompressible pairs.  */
          XSETCDR (pair, ltv_mark);
        }
 
@@ -932,7 +932,7 @@ lisp_to_value (Lisp_Object o)
   if (! EQ (o, value_to_lisp_bits (v)))
     {
-      /* Package the uncompressible object pointer inside a pair
+      /* Package the incompressible object pointer inside a pair
         that is compressible.  */
       Lisp_Object pair = Fcons (o, ltv_mark);